# PyRiesz
 Flexible PyTorch implementations of Auto-DML estimators of the Riesz Representer for causal effects estimation with machine learning.
 
Implements the multitask learning RieszNet architecture from [Chernozhukov, Newey, Quintas-Martı́nez, and Syrgkanis (2022, PMLR)](https://proceedings.mlr.press/v162/chernozhukov22a.html), as well as the LASSO estimator of the Riesz representation described in [Chernozhukov, Newey, and Singh (2022, Econometrica)](https://onlinelibrary.wiley.com/doi/abs/10.3982/ECTA18515)
